==> haskell-authenticate-1.3.5.2-205-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-6BCtaoTTSZFJU1hZte7MgP
key:                  authenticate-1.3.5.2-6BCtaoTTSZFJU1hZte7MgP
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  d412a1e330a191041163ed212f9f7134
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-6BCtaoTTSZFJU1hZte7MgP
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg
    attoparsec-0.14.4-DYbgeBOmAIRHL8NoYiOyFW
    attoparsec-aeson-2.1.0.0-DdR79qVZCk28xrg7JfXfeG base-4.17.2.1
    blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1 containers-0.6.7
    html-conduit-1.3.2.2-26htBbKDIvzEK7hYHyNZFB
    http-conduit-2.3.9.1-Ez7Wwb3oy5J4EzeufIRGd5
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    network-uri-2.6.4.2-6dAHdOyJLq76CXdDmIsqEl
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    xml-conduit-1.9.1.4-4j2T32Yc9L746h6qu9IdEP

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-234-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-AIb97hWgP35EI1lmbvPptG
key:                  authenticate-1.3.5.2-AIb97hWgP35EI1lmbvPptG
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  fcc9ae5b0437fc65c6fe36d4a27c872e
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-AIb97hWgP35EI1lmbvPptG
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    attoparsec-0.14.4-D6xkbFZLQBXDD0qvU7o55y
    attoparsec-aeson-2.1.0.0-BaIGvxJAWCx43bSANq38ez base-4.17.2.1
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3 containers-0.6.7
    html-conduit-1.3.2.2-36uiJMbfIgCLu2NEgQSZun
    http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    network-uri-2.6.4.2-DVBcu05aYxxCjTvpzOd17v
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    xml-conduit-1.9.1.4-93p77c2FG7W9C5BkdNl9oF

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
